// SPDX-FileCopyrightText: 2024 Aravinth Manivannan <realaravinth@batsense.net>
//
// SPDX-License-Identifier: AGPL-3.0-or-later

const express = require("express");
const path = require("path");
const nunjucks = require("nunjucks");
const app = express();
const port = 3000;
const MCaptcha = require("@mcaptcha/mcaptcha-api-js");
const bodyParser = require("body-parser");
require(dotenv).config();

let sitekey = process.env.SITEKEY;
let secret = process.env.SECRET;
let instance_url = process.env.INSTANCE_URL;
let mcaptcha = new MCaptcha(sitekey, secret, instance_url);

nunjucks.configure(path.join(__dirname, "../views"), {
  autoescape: true,
  express: app,
});

// app

app.use(express.static(__dirname));
app.use(bodyParser.urlencoded({extended: true}))
app.use(express.urlencoded());

app.get("/", async (req, res) =>
  res.render("index.html", {
    widget_link: `${instance_url}/widget?sitekey=${sitekey}`,
  })
);

app.post("/", async (req, res) => {
  let name = req.body.name;
  let commen = req.body.comment;
  let mcaptcha__token = req.body.mcaptcha__token;
  if (await mcaptcha.verify(mcaptcha__token)) {
    res.send("verified");
  } else {
    res.send("unverified");
  }
});

app.listen(port, () => console.log(`Example app listening on port ${port}!`));
